from .base import Base
from .model import Model


class Deployment(Base):
    def __init__(self,
                 model: Model,
                 environment: str = "",
                 instances: int = 1,
                 v_cores: int = 1
                 ):

        self.model = model
        self.environment = environment
        self.instances = environment
        self.v_cores = v_cores
        self.instances = instances



import os
from requests.structures import CaseInsensitiveDict
import requests
import json


class Base():
    def __init__(self):
        self.host = os.environ["NTIENT_HOST"]
        self.headers = CaseInsensitiveDict()
        self.headers["Authorization"] = f"Bearer {os.environ['NTIENT_TOKEN']}"

    def get_request(self, url, params=None):
        response = requests.get(url, headers=self.headers, params=params)
        self.check_response(response)
        return response.json()

    def post_request(self, url, data):
        response = requests.post(
            url, json=data, headers=self.headers)

        self.check_response(response)
        return response.json()

    def post_upload(self, url, files):
        response = requests.post(url, files=files, headers=self.headers)
        self.check_response(response)
        return response.json()

    def patch_request(self, url, data):
        response = requests.patch(
            url, json=data, headers=self.headers)
        self.check_response(response)
        return response.json()

    def check_response(self, response):
        if response.status_code not in [200, 201, 202, 203, 204]:
            raise requests.exceptions.HTTPError("Not Authorized")



from .model import Model
from .api import API
from .packager import Packager
import os
import getpass

if not os.environ.get("NTIENT_TOKEN"):
    print("Environment variable NTIENT_TOKEN not found.")

    token = getpass.getpass(
        prompt="Please input your NTIENT token. It can be found on the application home page. ")

    os.environ["NTIENT_TOKEN"] = token

if not os.environ.get("NTIENT_HOST"):
    print("Environment variable NTIENT_HOST not found.")
    host = None
    while True:
        host = input(
            "Please input your NTIENT host from application home page. Leave blank to use default https://api.ntient.ai/api. ")

        print(host)
        if ("http://" in host or "https://" in host) and "/api" in host:
            break

        if host == "" or host is None:
            break

    if host == "":
        host = "https://api.ntient.ai"

    os.environ["NTIENT_HOST"] = host



from setuptools import find_packages, setup

long_description = open("README.md").read()

setup(
    name='ntient',
    packages=find_packages(exclude=['tests']),
    version='0.1.5',
    description="Ntient Client Library",
    long_description=long_description,
    long_description_content_type='text/markdown',
    author="Joel Davenport",
    license="MIT",
    install_requires=['requests'],
    setup_requires=['pytest-runner==5.3.1', 'pytest-mock==3.6.1'],
    tests_require=["pytest==6.2.5", "pytest-mock==3.6.1", "scikit-learn==1.0.2", "tensorflow==2.7.0", "torch==1.10.1"],
    test_suite='tests'
)
